@@ -174,7 +174,7 @@ class AboutWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.label = QLabel(self)
-        AboutTxt = "<h3>Gngeo-gui</h3><p>" \
+        AboutTxt = "<h3>Gngeo-gui 0.0.3-3</h3><p>" \
                    "<img src=/opt/usr/share/icons/hicolor/64x64/apps/gngeo_gui.png /><br>" \
                    "GnGeo-gui is a Graphical User Interface for GnGeo<p> " \
                    "GnGeo emulates the NeoGeo gameconsole from SNK &#174;</p>" \
@@ -424,7 +424,7 @@ class keyWindow(QDialog):
         font.setPointSize(24)
 	# A-button
 	self.AkeySpinBox = QDoubleSpinBox()
-	self.AkeySpinBox.setRange(0, 300)
+	self.AkeySpinBox.setRange(0, 307)
 	self.AkeySpinBox.setValue(float(Akey))
 	self.AkeySpinBox.setMinimumSize(150,60)
 	self.AkeySpinBox.setDecimals(0)
@@ -434,7 +434,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.AButton, 1, 2)
 	# B-button
 	self.BkeySpinBox = QDoubleSpinBox()
-	self.BkeySpinBox.setRange(1, 300)
+	self.BkeySpinBox.setRange(1, 307)
 	self.BkeySpinBox.setValue(float(Bkey))
 	self.BkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("B"), 2, 0)
@@ -443,7 +443,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.BButton, 2, 2)
 	# C-button
 	self.CkeySpinBox = QDoubleSpinBox()
-	self.CkeySpinBox.setRange(1, 300)
+	self.CkeySpinBox.setRange(1, 307)
 	self.CkeySpinBox.setValue(float(Ckey))
 	self.CkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("C"), 3, 0)
@@ -452,7 +452,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.CButton, 3, 2)
 	# D-button
 	self.DkeySpinBox = QDoubleSpinBox()
-	self.DkeySpinBox.setRange(0, 300)
+	self.DkeySpinBox.setRange(0, 307)
 	self.DkeySpinBox.setValue(float(Dkey))
 	self.DkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("D"), 4, 0)
@@ -461,7 +461,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.DButton, 4, 2)
 	# Start-button
 	self.StartkeySpinBox = QDoubleSpinBox()
-	self.StartkeySpinBox.setRange(0, 300)
+	self.StartkeySpinBox.setRange(0, 307)
 	self.StartkeySpinBox.setValue(float(Startkey))
 	self.StartkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("START"), 5, 0)
@@ -470,7 +470,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.StartButton, 5, 2)
 	# Coin-button
 	self.CoinkeySpinBox = QDoubleSpinBox()
-	self.CoinkeySpinBox.setRange(0, 300)
+	self.CoinkeySpinBox.setRange(0, 307)
 	self.CoinkeySpinBox.setValue(float(Coinkey))
 	self.CoinkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("COIN"), 6, 0)
@@ -479,7 +479,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.CoinButton, 6, 2)
 	# Up-key
 	self.UpkeySpinBox = QDoubleSpinBox()
-	self.UpkeySpinBox.setRange(0, 300)
+	self.UpkeySpinBox.setRange(0, 307)
 	self.UpkeySpinBox.setValue(float(Upkey))
 	self.UpkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("UP"), 7, 0)
@@ -488,7 +488,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.UpButton, 7, 2)
 	# Down-key
 	self.DownkeySpinBox = QDoubleSpinBox()
-	self.DownkeySpinBox.setRange(0, 300)
+	self.DownkeySpinBox.setRange(0, 307)
 	self.DownkeySpinBox.setValue(float(Downkey))
 	self.DownkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("DOWN"), 8, 0)
@@ -497,7 +497,7 @@ class keyWindow(QDialog):
 	grid.addWidget(self.DownButton, 8, 2)
 	# Left-key
 	self.LeftkeySpinBox = QDoubleSpinBox()
-	self.LeftkeySpinBox.setRange(0, 300)
+	self.LeftkeySpinBox.setRange(0, 307)
 	self.LeftkeySpinBox.setValue(float(Leftkey))
 	self.LeftkeySpinBox.setDecimals(0)
 	grid.addWidget(QLabel("LEFT"), 9, 0)
